Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(225)

Unified Diff: pkg/shelf/lib/src/pipeline.dart

Issue 238813003: pkg/shelf: rename Stack to Pipeline (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: nit Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/shelf/lib/shelf.dart ('k') | pkg/shelf/lib/src/stack.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/shelf/lib/src/pipeline.dart
diff --git a/pkg/shelf/lib/src/stack.dart b/pkg/shelf/lib/src/pipeline.dart
similarity index 66%
rename from pkg/shelf/lib/src/stack.dart
rename to pkg/shelf/lib/src/pipeline.dart
index 3aacf72825db4475c745828a3f7b12ce2c6877be..016e5fc3696c297395f6b1f51f4032103db52584 100644
--- a/pkg/shelf/lib/src/stack.dart
+++ b/pkg/shelf/lib/src/pipeline.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library shelf.stack;
+library shelf.pipeline;
import 'handler.dart';
import 'middleware.dart';
@@ -10,36 +10,36 @@ import 'middleware.dart';
/// A helper that makes it easy to compose a set of [Middleware] and a
/// [Handler].
///
/// var handler = const Stack()
/// .addMiddleware(loggingMiddleware)
/// .addMiddleware(cachingMiddleware)
/// .addHandler(application);
-class Stack {
- final Stack _parent;
+class Pipeline {
+ final Pipeline _parent;
final Middleware _middleware;
- const Stack()
+ const Pipeline()
: _middleware = null,
_parent = null;
- Stack._(this._middleware, this._parent);
+ Pipeline._(this._middleware, this._parent);
- /// Returns a new [Stack] with [middleware] added to the existing set of
+ /// Returns a new [Pipeline] with [middleware] added to the existing set of
/// [Middleware].
///
/// [middleware] will be the last [Middleware] to process a request and
/// the first to process a response.
- Stack addMiddleware(Middleware middleware) =>
- new Stack._(middleware, this);
+ Pipeline addMiddleware(Middleware middleware) =>
+ new Pipeline._(middleware, this);
/// Returns a new [Handler] with [handler] as the final processor of a
/// [Request] if all of the middleware in the stack have passed the request
/// through.
Handler addHandler(Handler handler) {
if (_middleware == null) return handler;
return _parent.addHandler(_middleware(handler));
}
/// Exposes this stack of [Middleware] as a single middleware instance.
Middleware get middleware => addHandler;
}
« no previous file with comments | « pkg/shelf/lib/shelf.dart ('k') | pkg/shelf/lib/src/stack.dart » ('j') | no next file with comments »
@@ -10,36 +10,36 @@ import 'middleware.dart';
/// [Handler].
///
-/// var handler = const Stack()
+/// var handler = const Pipeline()
/// .addMiddleware(loggingMiddleware)
/// .addMiddleware(cachingMiddleware)
@@ -10,36 +10,36 @@ import 'middleware.dart';
/// Returns a new [Handler] with [handler] as the final processor of a
- /// [Request] if all of the middleware in the stack have passed the request
+ /// [Request] if all of the middleware in the pipeline have passed the request
/// through.
Handler addHandler(Handler handler) {
@@ -10,36 +10,36 @@ import 'middleware.dart';
return _parent.addHandler(_middleware(handler));
}
- /// Exposes this stack of [Middleware] as a single middleware instance.
+ /// Exposes this pipeline of [Middleware] as a single middleware instance.
Middleware get middleware => addHandler;
}

Powered by Google App Engine
This is Rietveld 408576698